import {
  StepperEvents,
  LabeledIcon,
  IconRunning,
  IconSuccessful,
  IconFailed,
  IconUnknown
} from "@ess-ics/ce-ui-common";
import { theme } from "../../style/Theme";

interface JobStatusProps {
  status: string | undefined;
}

const getStatus = (status: string) => {
  switch (status.toLowerCase()) {
    case StepperEvents.queued:
      return {
        label: "Queued",
        icon: IconRunning
      };
    case StepperEvents.running:
      return {
        label: "Running",
        icon: IconRunning
      };
    case StepperEvents.successful:
      return {
        label: "Successful",
        icon: IconSuccessful
      };
    case StepperEvents.failed:
      return {
        label: "Failed",
        icon: IconFailed
      };
    default:
      return {
        label: "Unknown",
        icon: IconUnknown
      };
  }
};

export const JobStatus = ({ status }: JobStatusProps) => {
  const convertedStatus = status ? status.toString().toLowerCase() : "";

  const activeStep = getStatus(convertedStatus);
  const Icon = activeStep.icon;

  return (
    <LabeledIcon
      label={activeStep.label}
      labelPosition="right"
      LabelProps={{
        color:
          convertedStatus === StepperEvents.failed
            ? theme.palette.status.fail.main
            : "inherit"
      }}
      Icon={() => <Icon size="medium" />}
    />
  );
};
